import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { range, line, curveLinearClosed } from 'd3';

// Tweak these.
const n = 8;
const radius = 200;
const factor = 1;

const width = 960;
const height = 960;
const centerX = width / 2;
const centerY = height / 2;

const data = range(n).map(i => ({
  x: Math.sin((i / n) * Math.PI * 2 * factor) * radius,
  y: Math.cos((i / n) * Math.PI * 2 * factor) * radius
}));

const p1 = data[0];
const p2 = data[1];
const dx = p1.x - p2.x;
const dy = p1.y - p2.y;
const segmentLength = Math.sqrt(dx * dx + dy * dy);

const polyline = line()
  .x(d => d.x)
  .y(d => d.y)
  .curve(curveLinearClosed);

const gray = n => `rgb(${n},${n},${n})`;

const App = () => {
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${centerX},${centerY})`}>
        {data.map(d => (
          <circle
            cx={d.x}
            cy={d.y}
            r={segmentLength}
            fill="none"
            stroke={gray(180)}
          />
        ))}
        {
          <path
            fill="none"
            stroke="#3866e9"
            strokeWidth={2}
            d={polyline(data)}
          />
        }
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);